@@ -3,10 +3,10 @@ from explorer.utils import allowed_query_pks, user_can_see_query
 
 
 def view_permission(request, **kwargs):
-    return app_settings.EXPLORER_PERMISSION_VIEW(request.user)\
+    return app_settings.EXPLORER_PERMISSION_VIEW(request)\
         or user_can_see_query(request, **kwargs)\
         or (app_settings.EXPLORER_TOKEN_AUTH_ENABLED()
-            and (request.META.get('HTTP_X_API_TOKEN') ==
+            and (request.headers.get('X-Api-Token') ==
                  app_settings.EXPLORER_TOKEN
                  or request.GET.get('token') == app_settings.EXPLORER_TOKEN))
 
@@ -17,9 +17,9 @@ def view_permission(request, **kwargs):
 
 
 def view_permission_list(request):
-    return app_settings.EXPLORER_PERMISSION_VIEW(request.user)\
+    return app_settings.EXPLORER_PERMISSION_VIEW(request)\
         or allowed_query_pks(request.user.id)
 
 
 def change_permission(request, *args, **kwargs):
-    return app_settings.EXPLORER_PERMISSION_CHANGE(request.user)
+    return app_settings.EXPLORER_PERMISSION_CHANGE(request)
