@@ -1,10 +1,11 @@
+import unittest
 from unittest.mock import patch
 
 from django.core.cache import cache
 from django.db import connection
 from django.test import TestCase
 
-from explorer import schema
+from explorer import app_settings, schema
 from explorer.app_settings import EXPLORER_DEFAULT_CONNECTION as CONN
 
 
@@ -70,6 +71,7 @@ class TestSchemaInfo(TestCase):
         tables = [x[0] for x in res]
         self.assertNotIn(database_view, tables)
 
+    @unittest.skipIf(not app_settings.ENABLE_TASKS, 'tasks not enabled')
     @patch('explorer.schema.do_async')
     def test_builds_async(self, mocked_async_check):
         mocked_async_check.return_value = True
