@@ -10,7 +10,7 @@ class EmailCsvQueryView(PermissionRequiredMixin, View):
     permission_required = 'view_permission'
 
     def post(self, request, query_id, *args, **kwargs):
-        if request.META.get('HTTP_X_REQUESTED_WITH') == 'XMLHttpRequest':
+        if request.headers.get('x-requested-with') == 'XMLHttpRequest':
             email = request.POST.get('email', None)
             if email:
                 execute_query.delay(query_id, email)
