@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
-from django.shortcuts import render
 from django.conf import settings
+from django.shortcuts import render
 
 from explorer import app_settings
 
@@ -16,6 +15,7 @@ class ExplorerContextMixin:
                 self.request
             ),
             'csrf_cookie_name': settings.CSRF_COOKIE_NAME,
+            'view_name': self.request.resolver_match.view_name,
         }
 
     def get_context_data(self, **kwargs):
